PagingManager class abstract

Implementers

Constructors

PagingManager({required List data, int pageSize = 10, int currentPage = 0})

Properties

currentPage ↔ int
getter/setter pair
data ↔ List
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
pageSize ↔ int
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

loadNextPage() → List
loadPage({int pageIndex = 0}) → List
loadPrevPage() → List
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited