PagingManagerImpl class

Inheritance
Mixed-in types

Constructors

PagingManagerImpl({required List data, int pageSize = 10, int currentPage = 0, PagingAlgorithmType algorithmType = PagingAlgorithmType.Sections})

Properties

algorithmType ↔ PagingAlgorithmType
getter/setter pair
currentPage ↔ int
getter/setter pairoverride
data ↔ List
getter/setter pairoverride
hashCode → int
The hash code for this object.
no setterinherited
pageSize ↔ int
getter/setter pairoverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getAddition(List data, int pageIndex, int pageSize) → List?
inherited
getSection(List data, int pageIndex, int pageSize) → List?
inherited
loadNextPage() → List
inherited
loadPage({int pageIndex = 0}) → List
override
loadPrevPage() → List
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited